@@ -27,7 +27,8 @@ class FileFormatter:
     @staticmethod
     def create_formatted_file(file, formatted_str):
         file_name, type_name = os.path.splitext(file)
-        formatted_file = file_name + '_formatted' + type_name
+        # formatted_file = file_name + '_formatted' + type_name
+        formatted_file = file_name + type_name
 
         text_file = open(formatted_file, "wt")
         text_file.write(formatted_str)
