@@ -442,6 +442,12 @@ class RubyCodeParser:
 
                     line = RubyCodeParser._convert_list_to_string(tmp, seperator=' ')
 
+                    tmp = RubyCodeParser._get_words_in_line(line)
+                    if tmp[len(tmp) - 1] == '<':
+                        del tmp[len(tmp) - 1]
+
+                    line = RubyCodeParser._convert_list_to_string(tmp, seperator=' ')
+
             new_list_of_lines.append(line)
 
         return new_list_of_lines
@@ -732,6 +738,12 @@ class RubyCodeParser:
 
         self.list_char_name = RubyCodeParser._get_chars_from_str(name_of_folder)
 
+        if self._is_const(name_of_folder):
+            del self.list_char_name[len(self.list_char_name)-5:len(self.list_char_name)]
+
+            if self.list_char_name[len(self.list_char_name)-1] == '_':
+                del self.list_char_name[len(self.list_char_name)-1]
+
         recommend_new_name = ''
 
         for i in range(len(self.list_char_name)):
@@ -770,6 +782,9 @@ class RubyCodeParser:
 
         if isScreaming_case:
             recommend_new_name = recommend_new_name.upper()
+            if self.list_char_name[len(self.list_char_name)-1] != '_':
+                recommend_new_name += '_'
+            recommend_new_name += 'CONST'
 
         if recommend_new_name != name_of_folder:
             logger.debug(f'You should name {name_of_folder} to {recommend_new_name}')
@@ -1670,4 +1685,4 @@ class RubyCodeParser:
         elif chars[index] == ':':
             chars.insert(index + 1, ' ')
 
-        return chars
+        return chars
\ No newline at end of file
